@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -249,14 +249,13 @@ class CloudFilestoreManagerAsyncClient:
         r"""Lists all instances in a project for either a
         specified location or for all locations.
 
-
         .. code-block:: python
 
             from google.cloud import filestore_v1
 
-            def sample_list_instances():
+            async def sample_list_instances():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.ListInstancesRequest(
@@ -267,7 +266,7 @@ class CloudFilestoreManagerAsyncClient:
                 page_result = client.list_instances(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -341,12 +340,20 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListInstancesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -367,9 +374,9 @@ class CloudFilestoreManagerAsyncClient:
 
             from google.cloud import filestore_v1
 
-            def sample_get_instance():
+            async def sample_get_instance():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.GetInstanceRequest(
@@ -377,7 +384,7 @@ class CloudFilestoreManagerAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_instance(request=request)
+                response = await client.get_instance(request=request)
 
                 # Handle the response
                 print(response)
@@ -444,7 +451,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -466,14 +478,13 @@ class CloudFilestoreManagerAsyncClient:
         capacity of the backup (and also equal to or larger than
         the minimum capacity of the tier).
 
-
         .. code-block:: python
 
             from google.cloud import filestore_v1
 
-            def sample_create_instance():
+            async def sample_create_instance():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.CreateInstanceRequest(
@@ -486,7 +497,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -570,7 +581,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -599,9 +615,9 @@ class CloudFilestoreManagerAsyncClient:
 
             from google.cloud import filestore_v1
 
-            def sample_update_instance():
+            async def sample_update_instance():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.UpdateInstanceRequest(
@@ -612,7 +628,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -689,7 +705,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -716,14 +737,13 @@ class CloudFilestoreManagerAsyncClient:
         larger than the capacity of the backup (and also equal
         to or larger than the minimum capacity of the tier).
 
-
         .. code-block:: python
 
             from google.cloud import filestore_v1
 
-            def sample_restore_instance():
+            async def sample_restore_instance():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.RestoreInstanceRequest(
@@ -737,7 +757,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -779,7 +799,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -807,9 +832,9 @@ class CloudFilestoreManagerAsyncClient:
 
             from google.cloud import filestore_v1
 
-            def sample_delete_instance():
+            async def sample_delete_instance():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.DeleteInstanceRequest(
@@ -821,7 +846,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -894,7 +919,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -919,14 +949,13 @@ class CloudFilestoreManagerAsyncClient:
         r"""Lists all backups in a project for either a specified
         location or for all locations.
 
-
         .. code-block:: python
 
             from google.cloud import filestore_v1
 
-            def sample_list_backups():
+            async def sample_list_backups():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.ListBackupsRequest(
@@ -937,7 +966,7 @@ class CloudFilestoreManagerAsyncClient:
                 page_result = client.list_backups(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1010,12 +1039,20 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListBackupsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1036,9 +1073,9 @@ class CloudFilestoreManagerAsyncClient:
 
             from google.cloud import filestore_v1
 
-            def sample_get_backup():
+            async def sample_get_backup():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.GetBackupRequest(
@@ -1046,7 +1083,7 @@ class CloudFilestoreManagerAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_backup(request=request)
+                response = await client.get_backup(request=request)
 
                 # Handle the response
                 print(response)
@@ -1113,7 +1150,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1135,9 +1177,9 @@ class CloudFilestoreManagerAsyncClient:
 
             from google.cloud import filestore_v1
 
-            def sample_create_backup():
+            async def sample_create_backup():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.CreateBackupRequest(
@@ -1150,7 +1192,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1239,7 +1281,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1267,9 +1314,9 @@ class CloudFilestoreManagerAsyncClient:
 
             from google.cloud import filestore_v1
 
-            def sample_delete_backup():
+            async def sample_delete_backup():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.DeleteBackupRequest(
@@ -1281,7 +1328,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1354,7 +1401,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1383,9 +1435,9 @@ class CloudFilestoreManagerAsyncClient:
 
             from google.cloud import filestore_v1
 
-            def sample_update_backup():
+            async def sample_update_backup():
                 # Create a client
-                client = filestore_v1.CloudFilestoreManagerClient()
+                client = filestore_v1.CloudFilestoreManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = filestore_v1.UpdateBackupRequest(
@@ -1396,7 +1448,7 @@ class CloudFilestoreManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1471,7 +1523,12 @@ class CloudFilestoreManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1493,7 +1550,9 @@ class CloudFilestoreManagerAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-filestore",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-filestore",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
